searchData={"content_type":"text/markdown","items":[{"doc":"This module provides macros that create structs with type-safe helper functions that would be found in OOP languages\nsuch as a constructor and getters / setters for each field. If a typing criteria is not followed then an exception\nis raised.","ref":"StructHelpers.html","title":"StructHelpers","type":"module"},{"doc":"Add to your mix.exs\n\n```elixir\n  [\n    {:struct_helpers, \"~> 0.1.3\"}\n  ]\n```","ref":"StructHelpers.html#module-installation","title":"Installation: - StructHelpers","type":"module"},{"doc":"```elixir\ndefmodule MyModule do\n  use StructHelpers\n\n  generate_constructor(__MODULE__, %{\n    field: :year,\n    type_guard: :is_integer,\n    default_value: 2,\n    nullable: false,\n    struct: nil\n  },\n  %{\n    field: :age,\n    type_guard: :is_integer,\n    default_value: 10,\n    nullable: true,\n    struct: nil\n  },\n  %{\n    field: :hair_details,\n    type_guard: :is_struct,\n    default_value: nil,\n    nullable: true,\n    struct: Hair\n  })\n\nend\n```","ref":"StructHelpers.html#module-setup","title":"Setup: - StructHelpers","type":"module"},{"doc":"```\nMyModule.constructor(\n  year: 10,\n  age: 20,\n  hair: Hair.constructor(\n    color: \"brown\",\n    type: \"wavy\"\n  )\n)\n```","ref":"StructHelpers.html#module-usage-application","title":"Usage / Application: - StructHelpers","type":"module"},{"doc":"Supports up to 30 attributes. If more than 30 attributes are needed you may use the generator script file (JavaScript) provided here:\n https://github.com/otboss/struct_helpers/blob/master/lib/generator.js \n\n**However** if a struct has greater than 30 attributes chances are that it may need to be broken down to abide by the SOLID principles.","ref":"StructHelpers.html#module-result","title":"Result: - StructHelpers","type":"module"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/2","title":"StructHelpers.generate_constructor/2","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/3","title":"StructHelpers.generate_constructor/3","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/4","title":"StructHelpers.generate_constructor/4","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/5","title":"StructHelpers.generate_constructor/5","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/6","title":"StructHelpers.generate_constructor/6","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/7","title":"StructHelpers.generate_constructor/7","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/8","title":"StructHelpers.generate_constructor/8","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/9","title":"StructHelpers.generate_constructor/9","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/10","title":"StructHelpers.generate_constructor/10","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/11","title":"StructHelpers.generate_constructor/11","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/12","title":"StructHelpers.generate_constructor/12","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/13","title":"StructHelpers.generate_constructor/13","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/14","title":"StructHelpers.generate_constructor/14","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/15","title":"StructHelpers.generate_constructor/15","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/16","title":"StructHelpers.generate_constructor/16","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/17","title":"StructHelpers.generate_constructor/17","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/18","title":"StructHelpers.generate_constructor/18","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/19","title":"StructHelpers.generate_constructor/19","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/20","title":"StructHelpers.generate_constructor/20","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/21","title":"StructHelpers.generate_constructor/21","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/22","title":"StructHelpers.generate_constructor/22","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/23","title":"StructHelpers.generate_constructor/23","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/24","title":"StructHelpers.generate_constructor/24","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/25","title":"StructHelpers.generate_constructor/25","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/26","title":"StructHelpers.generate_constructor/26","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/27","title":"StructHelpers.generate_constructor/27","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/28","title":"StructHelpers.generate_constructor/28","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/29","title":"StructHelpers.generate_constructor/29","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/30","title":"StructHelpers.generate_constructor/30","type":"macro"},{"doc":"Generates a struct, complete with a constructor, getter and setter methods.\n\nMacro usage example:\n    ```\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: %Hair{},\n      nullable: true,\n      struct: Hair\n    })\n    ```","ref":"StructHelpers.html#generate_constructor/31","title":"StructHelpers.generate_constructor/31","type":"macro"},{"doc":"# StructHelpers\n\n  This module provides macros that create structs with type-safe helper functions that would be found in OOP languages\n  such as a constructor and getters / setters for each field. If a typing criteria is not followed then an exception\n  is raised.","ref":"readme.html","title":"StructHelpers","type":"extras"},{"doc":"Add to your mix.exs\n\n  ```elixir\n    [\n      {:struct_helpers, \"~> 0.1.3\"}\n    ]\n  ```","ref":"readme.html#installation","title":"Installation: - StructHelpers","type":"extras"},{"doc":"```elixir\n  defmodule MyModule do\n    use StructHelpers\n\n    generate_constructor(__MODULE__, %{\n      field: :year,\n      type_guard: :is_integer,\n      default_value: 2,\n      nullable: false,\n      struct: nil\n    },\n    %{\n      field: :age,\n      type_guard: :is_integer,\n      default_value: 10,\n      nullable: true,\n      struct: nil\n    },\n    %{\n      field: :hair_details,\n      type_guard: :is_struct,\n      default_value: nil,\n      nullable: true,\n      struct: Hair\n    })\n\n  end\n  ```","ref":"readme.html#setup","title":"Setup: - StructHelpers","type":"extras"},{"doc":"```elixir\n  MyModule.constructor(\n    year: 10,\n    age: 20,\n    hair: Hair.constructor(\n      color: \"brown\",\n      type: \"wavy\"\n    )\n  )\n  ```","ref":"readme.html#usage-application","title":"Usage / Application: - StructHelpers","type":"extras"},{"doc":"Supports up to 30 attributes. If more than 30 attributes are needed you may use the generator script file (JavaScript) provided here:\n https://github.com/otboss/struct_helpers/blob/master/lib/generator.js \n\n**However** if a struct has greater than 30 attributes chances are that it may need to be broken down to abide by the SOLID principles.","ref":"readme.html#result","title":"Result: - StructHelpers","type":"extras"}]}